@@ -51,7 +51,7 @@ fn generate_function(attributes: &AttributeArgs, function: &ItemFn) -> Result<To
         #[no_mangle]
         unsafe extern "C" fn #function_name(
             stack: &mut #crate_path::cps::AsyncStack,
-            continue_: #crate_path::cps::ContinuationFunction<#output_type>,
+            continue_: #crate_path::cps::ContinuationFunction<#output_type, ()>,
             #arguments
         ) -> #crate_path::cps::Result {
             use std::{future::Future, pin::Pin, task::Poll};
@@ -66,7 +66,7 @@ fn generate_function(attributes: &AttributeArgs, function: &ItemFn) -> Result<To
 
             unsafe extern "C" fn poll(
                 stack: &mut #crate_path::cps::AsyncStack,
-                continue_: #crate_path::cps::ContinuationFunction<#output_type>,
+                continue_: #crate_path::cps::ContinuationFunction<#output_type, ()>,
                 mut future: OutputFuture,
             ) -> #crate_path::cps::Result {
                 match future.as_mut().poll(stack.context().unwrap()) {
@@ -80,7 +80,7 @@ fn generate_function(attributes: &AttributeArgs, function: &ItemFn) -> Result<To
 
             unsafe extern "C" fn resume(
                 stack: &mut #crate_path::cps::AsyncStack,
-                continue_: #crate_path::cps::ContinuationFunction<#output_type>,
+                continue_: #crate_path::cps::ContinuationFunction<#output_type, ()>,
             ) -> #crate_path::cps::Result {
                 let future = stack.restore().unwrap();
                 poll(stack, continue_, future)
